#[repr(C)]pub struct Var {
pub authority: Pubkey,
pub commit: [u8; 32],
pub seed: [u8; 32],
pub slot_hash: [u8; 32],
pub value: [u8; 32],
pub samples: u64,
pub is_auto: u64,
pub start_at: u64,
pub end_at: u64,
}Fields
The creator of the variable.
commit: [u8; 32]The commit provided by Entropy provider.
seed: [u8; 32]The revealed seed.
slot_hash: [u8; 32]The slot hash
value: [u8; 32]The current value of the variable.
samples: u64The number of random variables remaining to be sampled.
is_auto: u64Whether or not the Entropy provider should automatically sample the slot hash.
start_at: u64The slot at which the variable was opened.
end_at: u64The slot at which the variable should sample the slothash.
Implementations